@@ -4,7 +4,7 @@ from payfast.models import PayFastOrder
 class PayFastOrderAdmin(admin.ModelAdmin):
 
     list_display = ['m_payment_id', 'pf_payment_id', 'user', 'created_at', 'amount_gross',
-                    'payment_status', 'item_name']
+                    'payment_status', 'item_name', 'trusted']
     list_filter = ['trusted', 'payment_status']
     search_fields = ['m_payment_id', 'pf_payment_id', 'item_name',
                      'user__username', 'name_first', 'name_last', 'email_address']
