@@ -4,7 +4,7 @@ from django.core.urlresolvers import reverse
 from django.contrib.sites.models import Site
 
 from payfast.models import PayFastOrder
-from payfast.api import siganture, data_is_valid
+from payfast.api import signature, data_is_valid
 from payfast import conf
 
 def full_url(link):
@@ -100,7 +100,7 @@ class PayFastForm(HiddenForm):
         data = SortedDict()
         for key in self.fields.keys():
             data[key] = self.initial.get(key, None)
-        self._signature = self.fields['signature'].initial = siganture(data)
+        self._signature = self.fields['signature'].initial = signature(data)
 
 
 class NotifyForm(forms.ModelForm):
@@ -116,6 +116,18 @@ class NotifyForm(forms.ModelForm):
         if self.ip not in conf.IP_ADDRESSES:
             raise forms.ValidationError('untrusted ip: %s' % self.ip)
 
+        # signature is checked here because cleaned_data is not yet populated
+        # when clean_signature method is invoked
+        data = SortedDict()
+        for key in self.fields.keys():
+            if key == 'signature':
+                continue
+            data[key] = self.cleaned_data.get(key, None)
+
+        if signature(data) != self.cleaned_data['signature']:
+            raise forms.ValidationError('Signature is invalid: %s != %s' % (
+                        signature(data), self.cleaned_data['signature'],))
+
         if conf.USE_POSTBACK:
             is_valid = data_is_valid(self.request.POST, conf.SERVER)
             if is_valid is None:
@@ -141,9 +153,6 @@ class NotifyForm(forms.ModelForm):
                                             requested, received,))
         return received
 
-    def clean_signature(self):
-        return self.cleaned_data['signature']
-
     def save(self, *args, **kwargs):
         self.instance.request_ip = self.ip
         self.instance.debug_info = self.request.raw_post_data
